pyngrok Coverage Report

# pyngrok Coverage Report: 94.15%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 564 | 33 | 25 | 94.15%
pyngrok/__init__.py | 0 | 0 | 0 | 100.00%
pyngrok/conf.py | 29 | 1 | 0 | 96.55%
pyngrok/exception.py | 28 | 0 | 0 | 100.00%
pyngrok/installer.py | 129 | 6 | 4 | 95.35%
pyngrok/ngrok.py | 172 | 16 | 6 | 90.70%
pyngrok/process.py | 206 | 10 | 15 | 95.15%

No items found using the specified filter.